@@ -6,8 +6,8 @@ features Snowflake does not include at the moment.
 from typing import Optional
 from contextlib import closing
 
-from airflow.providers.snowflake.hooks.snowflake import SnowflakeHook
-from airflow.providers.postgres.hooks.postgres import PostgresHook
+from airflow.contrib.hooks.snowflake_hook import SnowflakeHook
+from airflow.hooks.postgres_hook import PostgresHook
 from airflow.models import BaseOperator
 from airflow.utils.decorators import apply_defaults
 
